# Changelog

## [unreleased]

### Features

- Project structure ([d46ab0a](d46ab0a0fc72cd0bac39fd5d6ed10db1d2b3da0f))
- Stable ([df03e02](df03e0279c59b761937168e00d7c6eeaa5da10d9))
- Implement timer ([3d7aeca](3d7aeca84638dca3cf046734b6028a8c16a21fbc))



<!-- generated by git-cliff -->
